==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchListenerBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterEnvoyConfigObjectMatchListenerBuilder extends EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl<EnvoyFilterEnvoyConfigObjectMatchListenerBuilder> implements VisitableBuilder<EnvoyFilterEnvoyConfigObjectMatchListener,EnvoyFilterEnvoyConfigObjectMatchListenerBuilder>{
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder() {
    this(false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterEnvoyConfigObjectMatchListener(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(EnvoyFilterEnvoyConfigObjectMatchListenerFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(EnvoyFilterEnvoyConfigObjectMatchListenerFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterEnvoyConfigObjectMatchListener(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(EnvoyFilterEnvoyConfigObjectMatchListenerFluent<?> fluent,EnvoyFilterEnvoyConfigObjectMatchListener instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(EnvoyFilterEnvoyConfigObjectMatchListenerFluent<?> fluent,EnvoyFilterEnvoyConfigObjectMatchListener instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withListener(instance.getListener());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(EnvoyFilterEnvoyConfigObjectMatchListener instance) {
    this(instance,false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(EnvoyFilterEnvoyConfigObjectMatchListener instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withListener(instance.getListener());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterEnvoyConfigObjectMatchListenerFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterEnvoyConfigObjectMatchListener build() {
    EnvoyFilterEnvoyConfigObjectMatchListener buildable = new EnvoyFilterEnvoyConfigObjectMatchListener(fluent.getListener());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchListenerBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterEnvoyConfigObjectMatchListenerBuilder extends EnvoyFilterEnvoyConfigObjectMatchListenerFluent<EnvoyFilterEnvoyConfigObjectMatchListenerBuilder> implements VisitableBuilder<EnvoyFilterEnvoyConfigObjectMatchListener,EnvoyFilterEnvoyConfigObjectMatchListenerBuilder>{
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder() {
    this(false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterEnvoyConfigObjectMatchListener(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(EnvoyFilterEnvoyConfigObjectMatchListenerFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(EnvoyFilterEnvoyConfigObjectMatchListenerFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterEnvoyConfigObjectMatchListener(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(EnvoyFilterEnvoyConfigObjectMatchListenerFluent<?> fluent,EnvoyFilterEnvoyConfigObjectMatchListener instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(EnvoyFilterEnvoyConfigObjectMatchListenerFluent<?> fluent,EnvoyFilterEnvoyConfigObjectMatchListener instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EnvoyFilterEnvoyConfigObjectMatchListener());

    if (instance != null) {
      fluent.withListener(instance.getListener());
      fluent.withListener(instance.getListener());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(EnvoyFilterEnvoyConfigObjectMatchListener instance) {
    this(instance,false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(EnvoyFilterEnvoyConfigObjectMatchListener instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EnvoyFilterEnvoyConfigObjectMatchListener());

    if (instance != null) {
      this.withListener(instance.getListener());
      this.withListener(instance.getListener());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterEnvoyConfigObjectMatchListenerFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterEnvoyConfigObjectMatchListener build() {
    EnvoyFilterEnvoyConfigObjectMatchListener buildable = new EnvoyFilterEnvoyConfigObjectMatchListener(fluent.buildListener());
    return buildable;
  }
  
}
